16.72. cdist-type__install_stage(7) — cdist 4.11.0 documentation

# 16.72. cdist-type__install_stage(7)

## 16.72.1. NAME

cdist-type__install_stage - download and unpack a stage file

## 16.72.2. DESCRIPTION

Downloads a operating system stage using curl and unpacks it to /target using tar. The stage tarball is expected to be gzip compressed.

## 16.72.3. REQUIRED PARAMETERS

uri
  The uri from which to fetch the tarball. Can be anything understood by curl, e.g: | http://path/to/stage.tgz | tftp:///path/to/stage.tgz | file:///local/path/stage.tgz

## 16.72.4. OPTIONAL PARAMETERS

target
  where to unpack the tarball to. Defaults to /target.

## 16.72.5. BOOLEAN PARAMETERS

insecure
  run curl in insecure mode so it does not check the servers ssl certificate

## 16.72.6. EXAMPLES

    __install_stage --uri tftp:///path/to/stage.tgz
    __install_stage --uri http://path/to/stage.tgz --target /mnt/foobar
    __install_stage --uri file:///path/to/stage.tgz --target /target
    __install_stage --uri https://path/to/stage.tgz --target /mnt/foobar --insecure

## 16.72.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.72.8. COPYING

Copyright (C) 2011 - 2013 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.